function stats =N2Qsim(specuminv,lambda,threshold,ntrials,varargin)
% function stats =N2Qsim(specuminv,lambda,threshold,ntrials)
%  Simulates a '1Q-2 bin PHA N2Q' detector. That is
%  measure total energy for whole spectrum but do 2 bin PHA on individual photons
%  and keep track of the 3 variables: Q, N1, N2
%  Does photon by photon Monte Carlo simulate of simultaneous count, integrated energy detector.
%  See subfunction CountEnergyNoiseLoc in NQxrayDetectorNoiseNormalApprox.m for another, less limited approach
%  inputs:
%      specuminv: (double vector) the inverse of the cumulative energy spectrum (range: [0 1])
%      lambda: the average value parameter of the count random variable
%          lambda is the parameter for the total number of counts so lambda = lambda_1 + lambda_2
%          The individual lambdas are implied by the threshold. 
%      ntrials: the number of trials in the simulation
%      add1: (optional = false) if specified replaces all 0 counts with 1
%  outputs:
%      stats: a struct with fields
%            lambda: the value of lambda
%            rho: (double ) the correlation coefficient of the photon numbers and integrated energy
%            dat: a 7 column (N,N1,N2,Q,Ebar,Ebar1,Ebar2) matrix of the photon numbers and total energy for each trial
%      also puts up plots of counts, energy histograms and scatterplot
% COPYRIGHT:   Aprend Technology, 2011. All rights reserved.
%  REA 3/30-2011-Dec-16 16:31

nreqargs = 4;
assert(nargin>=nreqargs);
add1 = false;
if(nargin>nreqargs)
  i=1;
  while(i<=size(varargin,2))
     switch lower(varargin{i})
     case 'add1';          add1=true;
     case 't_b';         t_b=varargin{i+1};   assert(isscalar(t_b));  i=i+1;
    otherwise
      error('Unknown argument %s given',varargin{i});
     end
     i=i+1;
  end
end

stats.lambda = lambda;
stat.specuminv = specuminv;

   % generate the number of photons for each trial
ns = poissrnd(lambda,ntrials,1); %poissrnd is matlab poisson random number generator
if add1
   ns(ns==0) = 1;
end

dat = zeros(ntrials,7); % N,N1,N2,Q, Ebar,Ebars(1:2)
dat(:,1) = ns;
for k=1:ntrials
      % compute random photon energies using inverse transform method
  photon_energies = specuminv(ceil(rand(1,ns(k))*numel(specuminv)));
       % number of counts in each PHA bin
  dat(k,2) = sum(double(photon_energies<threshold)); % sum number of logical '1'
  dat(k,3) = ns(k) - dat(k,2);
       % the total energy Q
  dat(k,4) = sum(photon_energies); 
  dat(k,5) = dat(k,4)/ns(k);
  dat(k,6) = mean(photon_energies(photon_energies<threshold));
  dat(k,7) = mean(photon_energies(photon_energies>=threshold));
end

if add1
   dat(dat(:,2)==0,2) = 1;
   dat(dat(:,3)==0,3) = 1;
end

stats.dat = dat;